@@ -129,6 +129,23 @@ class BuildAwareCommand(Command):
         :param upgrade: If set to `True`, ignore the lockfile and reinstall requirement spec.
         """
 
+        re_installed = self._install_or_reuse_env(build_env, project, upgrade)
+
+        if not re_installed:
+            requirements = project.get_requirement_spec()
+            local_requirements = [r for r in requirements.requirements if isinstance(r, LocalRequirement)]
+            if os.getenv("KRAKEN_ALWAYS_UPDATE_LOCAL_REQUIREMENTS") == "1" and local_requirements:
+                print(colored("Updating local requirements due to KRAKEN_ALWAYS_UPDATE_LOCAL_REQUIREMENTS=1", "blue"))
+                build_env.update_local_requirements(local_requirements)
+
+    def _install_or_reuse_env(
+        self,
+        build_env: BuildEnvironment,
+        project: ProjectInterface,
+        upgrade: bool = False,
+    ) -> bool:
+        """Installs the environment. Returns True if the entire environment was (re)installed."""
+
         if not build_env.exists():
             print(
                 colored(
@@ -186,7 +203,7 @@ class BuildAwareCommand(Command):
                     print(prefix + colored("Requirements in project:", "yellow"))
                     print(textwrap.indent(json.dumps(requirements.to_json(), indent=2), prefix + "  "))
 
-                return
+                return False
 
         if build_env.hash is not None and requirements.to_hash() != build_env.hash:
             print(
@@ -209,12 +226,8 @@ class BuildAwareCommand(Command):
         if install:
             build_env.install_requirements(requirements, upgrade)
             build_env.hash = requirements.to_hash()
-            return
 
-        local_requirements = [r for r in requirements.requirements if isinstance(r, LocalRequirement)]
-        if os.getenv("KRAKEN_ALWAYS_UPDATE_LOCAL_REQUIREMENTS") == "1" and local_requirements:
-            print(colored("Updating local requirements due to KRAKEN_ALWAYS_UPDATE_LOCAL_REQUIREMENTS=1", "blue"))
-            build_env.update_local_requirements(local_requirements)
+        return install
 
     def dispatch_to_build_environment(self, args: Args) -> int:
         """Dispatch to the build environment."""
