@@ -48,8 +48,6 @@ class EnvInfoCommand(BuildAwareCommand):
         print("    lockfile hash:", lockfile.requirements.to_hash() if lockfile else None)
         print(" environment hash:", build_env.hash)
         print(" environment path:", build_env.path, "" if build_env.exists() else "(does not exist)")
-        print()
-        print(requirements)
         return 0
 
 
